@@ -64,6 +64,7 @@ static NS_DEFINE_IID (kIPluginTagInfo2IID, NS_IPLUGINTAGINFO2_IID);
 
 static NPNetscapeFuncs browserFunctions;
 
+static GMutex *mutex_appletviewer_process = NULL;
 static gint send_message_to_appletviewer (gchar const* value);
 static gint receive_message_from_appletviewer (gchar* string);
 static gboolean callbackViewerRead (GIOChannel* source,
@@ -84,6 +85,8 @@ struct GCJPluginData
   char *instance_id;
 };
 
+static NPError start_appletviewer_process (void);
+
 static GIOChannel *output_to_appletviewer = NULL;
 static GIOChannel *input_from_appletviewer = NULL;
 
@@ -125,6 +128,16 @@ GCJ_New (NPMIMEType pluginType, NPP instance, uint16 mode,
   if (!instance)
     return NPERR_INVALID_INSTANCE_ERROR;
 
+  NPError tmp = NPERR_NO_ERROR;
+  
+  g_mutex_lock (mutex_appletviewer_process);
+  if (! output_to_appletviewer) // Start appletviewer process if necessary.
+    tmp = start_appletviewer_process();
+  g_mutex_unlock (mutex_appletviewer_process);
+
+  if (tmp != NPERR_NO_ERROR)
+    return tmp;
+
   GCJPluginData* data = NULL;
 
   gcjplugindata_new (&data);
@@ -188,8 +201,13 @@ GCJ_New (NPMIMEType pluginType, NPP instance, uint16 mode,
 	}
       else
         {
-	  applet_tag = g_strconcat (applet_tag,
-				    g_strdup_printf ("%s=\"%s\" ", argn[i], argv[i]), NULL);
+          // Escape the parameter value so that line termination
+          // characters will pass through the pipe.
+          if (argv[i] != '\0')
+            applet_tag = g_strconcat (applet_tag, argn[i],
+                                      "=\"",
+                                      g_strescape (argv[i], NULL),
+                                      "\" ", NULL);
         }
     }
   applet_tag = g_strconcat (applet_tag,
@@ -200,7 +218,7 @@ GCJ_New (NPMIMEType pluginType, NPP instance, uint16 mode,
   instance->pdata = data;
 
   char* tag = g_strdup_printf ("tag %s %s", data->documentbase, applet_tag);
-  
+
   send_message_to_appletviewer (data->instance_id);
   send_message_to_appletviewer (tag);
 
@@ -496,6 +514,30 @@ NP_Initialize(NPNetscapeFuncs* browserTable, NPPluginFuncs* pluginTable)
   pluginTable->urlnotify = NewNPP_URLNotifyProc(GCJ_URLNotify);
   pluginTable->getvalue = NewNPP_GetValueProc(GCJ_GetValue);
 
+  mutex_appletviewer_process = g_mutex_new ();
+  
+  return NPERR_NO_ERROR;
+}
+
+static NPError
+start_appletviewer_process(void)
+{
+
+  // Add install prefix to PATH.
+  char *searchpath = getenv("PATH");
+  char *newpath = NULL;
+  
+  if (searchpath != NULL)
+    {
+      newpath = strcat(searchpath, ":/home/mkoch/local/gcjwebplugin/bin");
+    }
+  else
+    {
+      newpath = "/home/mkoch/local/gcjwebplugin/bin";
+    }
+
+  setenv("PATH", newpath, 1);
+  
   // Create named pipes.
   gchar *pipename_in = g_strdup_printf ("/tmp/gcjwebplugin-%i-in", getpid ());
   gchar *pipename_out = g_strdup_printf ("/tmp/gcjwebplugin-%i-out", getpid ());
@@ -513,7 +555,6 @@ NP_Initialize(NPNetscapeFuncs* browserTable, NPPluginFuncs* pluginTable)
       g_printerr ("GCJ_New: Error: %s\n", strerror (errno));
       return NPERR_GENERIC_ERROR;
     }
-  
   GError *err = NULL;
   gchar *command_line [3] = {
     GCJAPPLETVIEWER_EXECUTABLE,
