@@ -28,13 +28,15 @@ import java.io.InputStreamReader;
 import java.io.StreamTokenizer;
 import java.net.MalformedURLException;
 import java.net.URL;
+import java.text.NumberFormat;
+import java.text.ParseException;
 import java.util.ArrayList;
 import java.util.HashMap;
 import java.util.Iterator;
 import java.util.List;
+import java.util.Locale;
 import java.util.StringTokenizer;
 
-
 class AppletTag
 {
   String name = "";
@@ -70,15 +72,15 @@ class AppletTag
     // When a class file is given on the command line, codebase is
     // always set to the empty string and documentbase is the
     // directory in which the class file resides.
-    String codebase =
+    String tmpCodeBase =
       code.substring(0, code.lastIndexOf(File.separatorChar) + 1);
-    if (codebase.startsWith(File.separator))
-      this.documentbase = new URL("file", "", codebase);
+    if (tmpCodeBase.startsWith(File.separator))
+      this.documentbase = new URL("file", "", tmpCodeBase);
     else
       // documentbase is the current working directory.
       this.documentbase =
 	new URL("file", "",
-	        System.getProperty("user.dir") + File.separator + codebase);
+	        System.getProperty("user.dir") + File.separator + tmpCodeBase);
 
     archivesList = archives;
     // Parse archives.
@@ -90,7 +92,7 @@ class AppletTag
       {
 	StringTokenizer paramTokenizer =
 	  new StringTokenizer((String) pairs.next(), ",");
-	this.parameters.put(paramTokenizer.nextToken().trim(),
+	this.parameters.put(paramTokenizer.nextToken().trim().toLowerCase(),
 	                    paramTokenizer.nextToken().trim());
       }
     this.parameters.put("width", Integer.toString(dimensions.width));
@@ -220,6 +222,7 @@ class AppletTag
 	else
 	  fullcodebase = new URL(documentbase, codebase + File.separator);
       }
+    
     return new URL(fullcodebase, basename);
   }
 
@@ -297,16 +300,17 @@ class AppletTag
 
   static URL locationToURL(String location) throws IOException
   {
-    URL documentbase = null;
+    URL tmpDocumentBase = null;
+    
     try
       {
 	// Try parsing location as a URL.
-	documentbase = new URL(location);
+	tmpDocumentBase = new URL(location);
 
 	// If no file was specified in the URL the assume the user
 	// meant the root page.
-	if (documentbase.getFile().equals(""))
-	  documentbase = new URL(location.concat(File.separator));
+	if (tmpDocumentBase.getFile().equals(""))
+	  tmpDocumentBase = new URL(location.concat(File.separator));
       }
     catch (MalformedURLException e)
       {
@@ -320,9 +324,9 @@ class AppletTag
 	    new File(System.getProperty("user.dir") + File.separator
 	             + location).getCanonicalPath();
 
-	documentbase = new URL("file", "", path);
+	tmpDocumentBase = new URL("file", "", path);
       }
-    return documentbase;
+    return tmpDocumentBase;
   }
 
   // Return a list of applet tag objects representing the applet tags
@@ -331,21 +335,19 @@ class AppletTag
     throws IOException
   {
     ArrayList tags = new ArrayList();
-    AppletTag currentTag;
-    InputStream input;
-    StreamTokenizer tagTokenizer;
-
-    URL documentbase = locationToURL(location);
-
-    input = documentbase.openStream();
-    tagTokenizer = new StreamTokenizer(new InputStreamReader(input));
-
-    currentTag = parseNextTag(tagTokenizer, documentbase, encoding);
+    URL tmpDocumentBase = locationToURL(location);
+    InputStream input = tmpDocumentBase.openStream();
+    StreamTokenizer tagTokenizer =
+      new StreamTokenizer(new InputStreamReader(input));
+    AppletTag currentTag =
+      parseNextTag(tagTokenizer, tmpDocumentBase, encoding);
+    
     while (currentTag != null)
       {
 	tags.add(currentTag);
-	currentTag = parseNextTag(tagTokenizer, documentbase, encoding);
+	currentTag = parseNextTag(tagTokenizer, tmpDocumentBase, encoding);
       }
+    
     return tags;
   }
 
@@ -430,6 +432,50 @@ class AppletTag
 	    + "  parameters=" + parameters + "\n" + "  documentbase="
 	    + documentbase + "\n");
   }
+
+  public static Dimension getSize (AppletTag tag)
+  {
+    NumberFormat numberFormat;
+    Dimension size = new Dimension();
+
+    try
+      {
+	String widthStr = (String) tag.parameters.get("width");
+
+	if (widthStr.charAt(widthStr.length() - 1) == '%')
+	  numberFormat = NumberFormat.getPercentInstance(Locale.US);
+	else
+	  numberFormat = NumberFormat.getInstance(Locale.US);
+
+	// FIXME: Handle percentage somehow.
+	size.width = numberFormat.parse(widthStr).intValue();
+      }
+    catch (ParseException e)
+      {
+	// Use default.
+	size.width = 320;
+      }
+
+    try
+      {
+	String heightStr = (String) tag.parameters.get("height");
+
+	if (heightStr.charAt(heightStr.length() - 1) == '%')
+	  numberFormat = NumberFormat.getPercentInstance(Locale.US);
+	else
+	  numberFormat = NumberFormat.getInstance(Locale.US);
+
+	// FIXME: Handle percentage somehow.
+	size.height = numberFormat.parse(heightStr).intValue();
+      }
+    catch (ParseException e)
+      {
+	// Use default.
+	size.height = 200;
+      }
+
+    return size;
+  }
 }
 
 
@@ -653,7 +699,7 @@ class ObjectTag extends AppletTag
   // Parse an applet parameter.
   void parseParam(StreamTokenizer tagTokenizer) throws IOException
   {
-    String name = null;
+    String paramName = null;
     String value = null;
 
     while (tagTokenizer.nextToken() != '>')
@@ -664,70 +710,70 @@ class ObjectTag extends AppletTag
 	      {
 		tagTokenizer.nextToken();
 		tagTokenizer.nextToken();
-		name = new String(tagTokenizer.sval).toLowerCase();
+		paramName = new String(tagTokenizer.sval).toLowerCase();
 	      }
 	    else if (tagTokenizer.sval.equals("value"))
 	      value = parseParamValue(tagTokenizer);
 	  }
 
-	if (name != null && value != null)
+	if (paramName != null && value != null)
 	  {
-	    if (name.equals("code"))
+	    if (paramName.equals("code"))
 	      {
 		if (javaCodeSet)
 		  // Interpret non-prefixed attribute as a parameter.
-		  parameters.put(name, value);
+		  parameters.put(paramName, value);
 		else
 		  {
 		    code = value;
 		    codeSet = true;
 		  }
 	      }
-	    else if (name.equals("java_code"))
+	    else if (paramName.equals("java_code"))
 	      {
 		if (codeSet)
 		  parameters.put("code", code);
 		code = value;
 		javaCodeSet = true;
 	      }
-	    else if (name.equals("object"))
+	    else if (paramName.equals("object"))
 	      {
 		if (javaObjectSet)
-		  parameters.put(name, value);
+		  parameters.put(paramName, value);
 		else
 		  {
 		    code = value;
 		    objectSet = true;
 		  }
 	      }
-	    else if (name.equals("java_object"))
+	    else if (paramName.equals("java_object"))
 	      {
 		if (objectSet)
 		  parameters.put("object", code);
 		code = value;
 		javaObjectSet = true;
 	      }
-	    else if (name.equals("codebase"))
+	    else if (paramName.equals("codebase"))
 	      {
 		if (javaCodebaseSet)
-		  parameters.put(name, value);
+		  parameters.put(paramName, value);
 		else
 		  {
 		    codebase = value;
 		    codebaseSet = true;
 		  }
 	      }
-	    else if (name.equals("java_codebase"))
+	    else if (paramName.equals("java_codebase"))
 	      {
 		if (codebaseSet)
 		  parameters.put("codebase", codebase);
 		codebase = value;
 		javaCodebaseSet = true;
 	      }
-	    else if (name.equals("archive"))
+	    else if (paramName.equals("archive"))
 	      {
 		if (javaArchiveSet)
-		  parameters.put(name, value);
+		  parameters.put(paramName, value);
 		else
 		  {
 		    // Save the archive list for later processing.
@@ -735,17 +781,18 @@ class ObjectTag extends AppletTag
 		    archiveSet = true;
 		  }
 	      }
-	    else if (name.equals("java_archive"))
+	    else if (paramName.equals("java_archive"))
 	      {
 		if (archiveSet)
 		  parameters.put("archive", archivesList);
 		archivesList = value;
 		javaArchiveSet = true;
 	      }
-	    else if (! name.equals("type") && ! name.equals("java_type")
-	             && ! name.equals("mayscript")
-	             && ! name.equals("scriptable"))
-	      parameters.put(name, value);
+	    else if (! paramName.equals("type")
+		     && ! paramName.equals("java_type")
+	             && ! paramName.equals("mayscript")
+	             && ! paramName.equals("scriptable"))
+	      parameters.put(paramName, value);
 	  }
       }
   }
