@@ -83,7 +83,7 @@ class AppletViewer
 	String code = tag.code;
 
 	if (code.endsWith(".class"))
-	  code = code.substring(0, code.length() - 6);
+	  code = code.substring(0, code.length() - 6).replace('/', '.');
 
 	Class c = loader.loadClass(code);
 	applet = (Applet) c.newInstance();
