@@ -95,7 +95,7 @@ class CommonAppletStub
    */
   public String getParameter(String name)
   {
-    return (String) tag.parameters.get(name);
+    return (String) tag.parameters.get(name.toLowerCase());
   }
 
   /**
