@@ -24,7 +24,6 @@ package gnu.getopt;
 
 import java.util.Locale;
 import java.util.ResourceBundle;
-import java.util.PropertyResourceBundle;
 import java.text.MessageFormat;
 
 /**************************************************************************/
@@ -540,8 +539,8 @@ protected String progname;
 /**
   * The localized strings are kept in a separate file
   */
-private ResourceBundle _messages = PropertyResourceBundle.getBundle(
-                           "core:/gnu/getopt/MessagesBundle", Locale.getDefault());
+private ResourceBundle _messages
+  = ResourceBundle.getBundle("gnu.getopt.MessagesBundle");
 
 /**************************************************************************/
 
@@ -619,8 +618,8 @@ Getopt(String progname, String[] argv, String optstring,
   else
     {
       posixly_correct = true;
-      _messages = PropertyResourceBundle.getBundle("core:/gnu/getopt/MessagesBundle",
-                                                   Locale.US);
+      _messages = ResourceBundle.getBundle("gnu.getopt.MessagesBundle",
+                                           Locale.US);
     }
 
   // Determine how to handle the ordering of options and non-options
