@@ -36,7 +36,7 @@ exception statement from your version. */
 
 #include <glib.h>
 
-#if 1
+#ifdef DEBUG
 
 #define PLUGIN_DEBUG(arg)		g_printerr ("GCJ PLUGIN: %s",          arg)
 #define PLUGIN_DEBUG2(output, arg)	g_printerr ("GCJ PLUGIN: " output, arg);
