@@ -1,3 +1,4 @@
+import java.awt.*;
 import java.applet.*;
 import java.io.*;
 import java.util.*;
@@ -30,5 +31,8 @@ public class TestAppletCodebaseOne1 extends Applet
   public void start ()
   {
     System.out.println ("TestAppletCodebaseOne1.start");
+    System.out.println ("codebase one 1 applet current keyboard manager: " + KeyboardFocusManager.getCurrentKeyboardFocusManager ());
+    System.out.println ("codebase one 1 applet context: " + getAppletContext ());
+    System.out.println ("codebase one 1 thread group: " + Thread.currentThread ().getThreadGroup ());
   }
 }
