@@ -1,14 +1,10 @@
+import java.awt.*;
 import java.applet.*;
 import java.io.*;
 import java.util.*;
 
 public class TestAppletNamed1 extends Applet
 {
-  public String getName ()
-  {
-    return "test applet 1";
-  }
-
   public void init () throws java.io.IOException
   {
     System.out.println ("TestAppletNamed1.init");
@@ -25,10 +21,18 @@ public class TestAppletNamed1 extends Applet
     ac.setStream ("applet 1 stream 2", new PipedInputStream ());
     ac.setStream ("applet 1 stream 3", new PipedInputStream ());
     ac.setStream ("applet 1 stream 4", new PipedInputStream ());
+
+//     KeyboardFocusManager m = new DefaultKeyboardFocusManager ();
+
+//     System.out.println ("applet 1 setting keyboard manager: " + m);
+
+//     KeyboardFocusManager.setCurrentKeyboardFocusManager (m);
   }
 
   public void start ()
   {
     System.out.println ("TestAppletNamed1.start");
+
+    System.out.println ("applet 1 current keyboard manager: " + KeyboardFocusManager.getCurrentKeyboardFocusManager ());
   }
 }
