@@ -1,14 +1,10 @@
+import java.awt.*;
 import java.applet.*;
 import java.io.*;
 import java.util.*;
 
 public class TestAppletNamed2 extends Applet
 {
-  public String getName ()
-  {
-    return "test applet 2";
-  }
-
   public void init () throws java.io.IOException
   {
     System.out.println ("TestAppletNamed2.init");
@@ -28,10 +24,18 @@ public class TestAppletNamed2 extends Applet
     ac.setStream ("applet 2 stream 5", new PipedInputStream ());
     ac.setStream ("applet 2 stream 6", new PipedInputStream ());
     ac.setStream ("applet 2 stream 7", new PipedInputStream ());
+
+//     KeyboardFocusManager m = new DefaultKeyboardFocusManager ();
+
+//     System.out.println ("applet 2 setting keyboard manager: " + m);
+
+//     KeyboardFocusManager.setCurrentKeyboardFocusManager (m);
   }
 
   public void start ()
   {
     System.out.println ("TestAppletNamed2.start");
+
+    System.out.println ("applet 2 current keyboard manager: " + KeyboardFocusManager.getCurrentKeyboardFocusManager ());
   }
 }
